@@ -12,6 +12,8 @@ from .tasks import (
     list_tasks,
     upload_annotations,
     upload_images,
+    upload_video,
+    upload_videos,
 )
 
 
@@ -31,5 +33,7 @@ def main() -> None:
             "list-tasks": list_tasks,
             "upload-annotations": upload_annotations,
             "upload-images": upload_images,
+            "upload-video": upload_video,
+            "upload-videos": upload_videos,
         }
     )
